pub struct AdminViewSitesTemplate { /* private fields */ }Trait Implementations
Sourceimpl Display for AdminViewSitesTemplate
Implement the format!() trait for AdminViewSitesTemplate
impl Display for AdminViewSitesTemplate
Implement the format!() trait for AdminViewSitesTemplate
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl FastWritable for AdminViewSitesTemplate
impl FastWritable for AdminViewSitesTemplate
Sourcefn write_into<AskamaW>(
&self,
dest: &mut AskamaW,
values: &dyn Values,
) -> Result<()>
fn write_into<AskamaW>( &self, dest: &mut AskamaW, values: &dyn Values, ) -> Result<()>
Used internally by askama to speed up writing some types.
Sourceimpl Template for AdminViewSitesTemplate
impl Template for AdminViewSitesTemplate
Sourceconst SIZE_HINT: usize = 1925usize
const SIZE_HINT: usize = 1925usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values<AskamaW>(
&self,
__askama_writer: &mut AskamaW,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values<AskamaW>( &self, __askama_writer: &mut AskamaW, __askama_values: &dyn Values, ) -> Result<()>
Renders the template to the given
writer fmt buffer with provided Values.Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it.Sourcefn render_with_values(&self, values: &dyn Values) -> Result<String, Error>
fn render_with_values(&self, values: &dyn Values) -> Result<String, Error>
Helper method which allocates a new
String and renders into it with provided Values.Sourcefn render_into<W>(&self, writer: &mut W) -> Result<(), Error>
fn render_into<W>(&self, writer: &mut W) -> Result<(), Error>
Renders the template to the given
writer fmt buffer.Auto Trait Implementations
impl Freeze for AdminViewSitesTemplate
impl RefUnwindSafe for AdminViewSitesTemplate
impl Send for AdminViewSitesTemplate
impl Sync for AdminViewSitesTemplate
impl Unpin for AdminViewSitesTemplate
impl UnsafeUnpin for AdminViewSitesTemplate
impl UnwindSafe for AdminViewSitesTemplate